pub enum ContextOmissionReason {
MaxItems,
OverBudget,
}Expand description
Reason a context item was not selected for a ContextPack.
Variants
MaxItems
The pack already reached ContextPackConfig::max_items.
OverBudget
Adding the item would exceed the available character budget.